@@ -83,4 +83,12 @@ Q10 = function(Q10, R1, R2, T1, T2, R_vec, T_vec, model = FALSE){
 			return(T1)
 		}
 	}
-}
\ No newline at end of file
+}
+
+#' @rdname Q10
+#' @export
+q10 = Q10
+
+#' @rdname Q10
+#' @export
+calc_q10 = Q10
\ No newline at end of file
